cmoncrawl.processor.pipeline.streamer.BaseStreamerFile.clean\_up
================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.streamer

.. automethod:: BaseStreamerFile.clean_up